@@ -38,8 +38,8 @@ class CardPort : public Port
     Q_OBJECT
     Q_PROPERTY(QVariantMap properties READ properties NOTIFY propertiesChanged)
 public:
-    CardPort(QObject *parent = nullptr) : Port(parent) {}
-    virtual ~CardPort() {}
+    explicit CardPort(QObject *parent = nullptr) : Port(parent) {}
+    ~CardPort() override {}
 
 //    int direction;                      /**< A #pa_direction enum, indicating the direction of this port. */
 //    uint32_t n_profiles;                /**< Number of entries in profile array */
@@ -63,12 +63,12 @@ public:
             Q_ASSERT(value);
             m_properties.insert(QString::fromUtf8(key), QString::fromUtf8(value));
         }
-        emit propertiesChanged();
+        Q_EMIT propertiesChanged();
     }
 
     QVariantMap properties() const { return m_properties; }
 
-signals:
+Q_SIGNALS:
     void propertiesChanged();
 
 private:
@@ -83,7 +83,7 @@ class Card : public PulseObject
     Q_PROPERTY(quint32 activeProfileIndex READ activeProfileIndex WRITE setActiveProfileIndex NOTIFY activeProfileIndexChanged)
     Q_PROPERTY(QList<QObject *> ports READ ports NOTIFY portsChanged)
 public:
-    Card(QObject *parent);
+    explicit Card(QObject *parent);
 
     void update(const pa_card_info *info);
 
@@ -93,7 +93,7 @@ public:
     void setActiveProfileIndex(quint32 profileIndex);
     QList<QObject *> ports() const;
 
-signals:
+Q_SIGNALS:
     void nameChanged();
     void profilesChanged();
     void activeProfileIndexChanged();
