@@ -25,7 +25,6 @@ namespace QPulseAudio
 
 Port::Port(QObject *parent)
     : Profile(parent)
-    , m_availability(Unknown)
 {
 }
 
@@ -33,9 +32,4 @@ Port::~Port()
 {
 }
 
-Port::Availability Port::availability() const
-{
-    return m_availability;
-}
-
 } // QPulseAudio
