@@ -53,12 +53,12 @@ void StreamRestore::update(const pa_ext_stream_restore_info *info)
         m_muted = info->mute;
         Q_EMIT mutedChanged();
     }
-    if (memcmp(&m_volume, &info->volume, sizeof(pa_cvolume)) != 0) {
+    if (!pa_cvolume_equal(&m_volume, &info->volume)) {
         m_volume = info->volume;
         Q_EMIT volumeChanged();
         Q_EMIT channelVolumesChanged();
     }
-    if (memcmp(&m_channelMap, &info->channel_map, sizeof(pa_channel_map)) != 0) {
+    if (pa_channel_map_equal(&m_channelMap, &info->channel_map)) {
         m_channels.clear();
         m_channels.reserve(info->channel_map.channels);
         for (int i = 0; i < info->channel_map.channels; ++i) {
